@@ -4,11 +4,13 @@ from werkzeug.datastructures import Headers
 from werkzeug.datastructures import ImmutableMultiDict
 
 from openapi_core.contrib.werkzeug.requests import WerkzeugOpenAPIRequest
-from openapi_core.validation.request.datatypes import RequestParameters
+from openapi_core.datatypes import RequestParameters
 
 
 class FlaskOpenAPIRequest(WerkzeugOpenAPIRequest):
     def __init__(self, request: Request):
+        if not isinstance(request, Request):
+            raise TypeError(f"'request' argument is not type of {Request}")
         self.request: Request = request
 
         self.parameters = RequestParameters(
@@ -21,6 +23,7 @@ class FlaskOpenAPIRequest(WerkzeugOpenAPIRequest):
     @property
     def path_pattern(self) -> str:
         if self.request.url_rule is None:
-            return self.request.path
+            return self.path
 
-        return self.path_regex.sub(r"{\1}", self.request.url_rule.rule)
+        path = self.get_path(self.request.url_rule.rule)
+        return self.path_regex.sub(r"{\1}", path)
