@@ -14,7 +14,6 @@ from openapi_core.unmarshalling.schemas.unmarshallers import (
 )
 from openapi_core.unmarshalling.schemas.unmarshallers import SchemaUnmarshaller
 from openapi_core.unmarshalling.schemas.unmarshallers import TypesUnmarshaller
-from openapi_core.validation.schemas.datatypes import CustomFormattersDict
 from openapi_core.validation.schemas.datatypes import FormatValidatorsDict
 from openapi_core.validation.schemas.factories import SchemaValidatorsFactory
 
@@ -25,23 +24,12 @@ class SchemaUnmarshallersFactory:
         schema_validators_factory: SchemaValidatorsFactory,
         types_unmarshaller: TypesUnmarshaller,
         format_unmarshallers: Optional[FormatUnmarshallersDict] = None,
-        custom_formatters: Optional[CustomFormattersDict] = None,
     ):
         self.schema_validators_factory = schema_validators_factory
         self.types_unmarshaller = types_unmarshaller
         if format_unmarshallers is None:
             format_unmarshallers = {}
         self.format_unmarshallers = format_unmarshallers
-        if custom_formatters is None:
-            custom_formatters = {}
-        else:
-            warnings.warn(
-                "custom_formatters is deprecated. "
-                "Use extra_format_validators to validate custom formats "
-                "and use extra_format_unmarshallers to unmarshal custom formats.",
-                DeprecationWarning,
-            )
-        self.custom_formatters = custom_formatters
 
     def create(
         self,
@@ -60,12 +48,6 @@ class SchemaUnmarshallersFactory:
 
         if extra_format_validators is None:
             extra_format_validators = {}
-        extra_format_validators.update(
-            {
-                name: formatter.validate
-                for name, formatter in self.custom_formatters.items()
-            }
-        )
         schema_validator = self.schema_validators_factory.create(
             schema,
             format_validators=format_validators,
@@ -77,7 +59,6 @@ class SchemaUnmarshallersFactory:
         formats_unmarshaller = FormatsUnmarshaller(
             format_unmarshallers or self.format_unmarshallers,
             extra_format_unmarshallers,
-            self.custom_formatters,
         )
 
         # FIXME: don;t raise exception on unknown format
